package com.winhc.repal.service.impl;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.winhc.repal.entity.RepalGroup;
import com.winhc.repal.entity.RepalGroupMember;
import com.winhc.repal.enums.DeletedStatusEnum;
import com.winhc.repal.enums.RoleTypeEnum;
import com.winhc.repal.model.dto.InitGroupDTO;
import com.winhc.repal.repository.RepalGroupMapper;
import com.winhc.repal.service.RepalGroupMemberService;
import com.winhc.repal.service.RepalGroupService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Objects;

/**
 * @description RepalGroup 接口实现类
 * @author Generator
 * @date 2022-04-13
 */
@Service
public class RepalGroupServiceImpl extends ServiceImpl<RepalGroupMapper, RepalGroup> implements RepalGroupService {

    private static final Logger LOGGER = LoggerFactory.getLogger(RepalGroupServiceImpl.class);

    @Autowired
    private RepalGroupMemberService repalGroupMemberService;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean initGroup(InitGroupDTO dto) {
        // member判断
        if (repalGroupMemberService.count(Wrappers.lambdaQuery(RepalGroupMember.class)
                .eq(RepalGroupMember::getUserId, dto.getUserId())
                .eq(RepalGroupMember::getDeleted, DeletedStatusEnum.NORMAL.getCode())) > 0) {
            LOGGER.info("已经属于组织成员了, userId:[{}]", dto.getUserId());
            return true;
        }

        RepalGroup repalGroup = this.getOne(Wrappers.lambdaQuery(RepalGroup.class)
                .eq(RepalGroup::getUserId, dto.getUserId())
                .eq(RepalGroup::getDeleted, DeletedStatusEnum.NORMAL.getCode()));
        if (Objects.isNull(repalGroup)) {
            repalGroup = new RepalGroup();
            repalGroup.setGroupName(dto.getGroupName());
            repalGroup.setUserId(dto.getUserId());
            repalGroup.setGroupExt(dto.getGroupExt());
            this.save(repalGroup);
            repalGroupMemberService.addGroupMember(dto.getUserId(), repalGroup.getId(), 1L, RoleTypeEnum.SYSTEM.getCode());
        }
        return true;
    }
}
